==> tekton-model-triggers-5.10.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/GitHubInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class GitHubInterceptorFluentImpl<A extends io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent<A>{
  public GitHubInterceptorFluentImpl() {
  }
  public GitHubInterceptorFluentImpl(io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptor instance) {
    this.withEventTypes(instance.getEventTypes()); 
    this.withSecretRef(instance.getSecretRef()); 
  }
  private java.util.List<java.lang.String> eventTypes;
  private io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder secretRef;
  public A addToEventTypes(java.lang.Integer index,java.lang.String item) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    this.eventTypes.add(index, item);
    return (A)this;
  }
  public A setToEventTypes(java.lang.Integer index,java.lang.String item) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    this.eventTypes.set(index, item); return (A)this;
  }
  public A addToEventTypes(java.lang.String... items) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A addAllToEventTypes(java.util.Collection<java.lang.String> items) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A removeFromEventTypes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public A removeAllFromEventTypes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getEventTypes() {
    return this.eventTypes;
  }
  public java.lang.String getEventType(java.lang.Integer index) {
    return this.eventTypes.get(index);
  }
  public java.lang.String getFirstEventType() {
    return this.eventTypes.get(0);
  }
  public java.lang.String getLastEventType() {
    return this.eventTypes.get(eventTypes.size() - 1);
  }
  public java.lang.String getMatchingEventType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: eventTypes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingEventType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: eventTypes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEventTypes(java.util.List<java.lang.String> eventTypes) {
    if (eventTypes != null) {this.eventTypes = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : eventTypes){this.addToEventTypes(item);}} else { this.eventTypes = null;} return (A) this;
  }
  public A withEventTypes(java.lang.String... eventTypes) {
    if (this.eventTypes != null) {this.eventTypes.clear();}
    if (eventTypes != null) {for (java.lang.String item :eventTypes){ this.addToEventTypes(item);}} return (A) this;
  }
  public java.lang.Boolean hasEventTypes() {
    return eventTypes != null && !eventTypes.isEmpty();
  }
  public A addNewEventType(java.lang.String arg0) {
    return (A)addToEventTypes(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.tekton.triggers.v1alpha1.SecretRef getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.tekton.triggers.v1alpha1.SecretRef buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.tekton.triggers.v1alpha1.SecretRef secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String secretKey,java.lang.String secretName) {
    return (A)withSecretRef(new SecretRef(secretKey, secretName));
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.tekton.triggers.v1alpha1.SecretRef item) {
    return new io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder().build());
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.tekton.triggers.v1alpha1.SecretRef item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitHubInterceptorFluentImpl that = (GitHubInterceptorFluentImpl) o;
    if (eventTypes != null ? !eventTypes.equals(that.eventTypes) :that.eventTypes != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(eventTypes,  secretRef,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.tekton.triggers.v1alpha1.SecretRefFluentImpl<io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<N>> implements io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.tekton.triggers.v1alpha1.SecretRef item) {
      this.builder = new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder(this);
    }
    io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder builder;
    public N and() {
      return (N) GitHubInterceptorFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-5.12.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/GitHubInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class GitHubInterceptorFluentImpl<A extends io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent<A>{
  public GitHubInterceptorFluentImpl() {
  }
  public GitHubInterceptorFluentImpl(io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptor instance) {
    this.withEventTypes(instance.getEventTypes()); 
    this.withSecretRef(instance.getSecretRef()); 
  }
  private java.util.List<java.lang.String> eventTypes;
  private io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder secretRef;
  public A addToEventTypes(java.lang.Integer index,java.lang.String item) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    this.eventTypes.add(index, item);
    return (A)this;
  }
  public A setToEventTypes(java.lang.Integer index,java.lang.String item) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    this.eventTypes.set(index, item); return (A)this;
  }
  public A addToEventTypes(java.lang.String... items) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A addAllToEventTypes(java.util.Collection<java.lang.String> items) {
    if (this.eventTypes == null) {this.eventTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A removeFromEventTypes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public A removeAllFromEventTypes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getEventTypes() {
    return this.eventTypes;
  }
  public java.lang.String getEventType(java.lang.Integer index) {
    return this.eventTypes.get(index);
  }
  public java.lang.String getFirstEventType() {
    return this.eventTypes.get(0);
  }
  public java.lang.String getLastEventType() {
    return this.eventTypes.get(eventTypes.size() - 1);
  }
  public java.lang.String getMatchingEventType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: eventTypes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingEventType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: eventTypes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEventTypes(java.util.List<java.lang.String> eventTypes) {
    if (eventTypes != null) {this.eventTypes = new java.util.ArrayList(); for (java.lang.String item : eventTypes){this.addToEventTypes(item);}} else { this.eventTypes = null;} return (A) this;
  }
  public A withEventTypes(java.lang.String... eventTypes) {
    if (this.eventTypes != null) {this.eventTypes.clear();}
    if (eventTypes != null) {for (java.lang.String item :eventTypes){ this.addToEventTypes(item);}} return (A) this;
  }
  public java.lang.Boolean hasEventTypes() {
    return eventTypes != null && !eventTypes.isEmpty();
  }
  public A addNewEventType(java.lang.String arg0) {
    return (A)addToEventTypes(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.tekton.triggers.v1alpha1.SecretRef getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.tekton.triggers.v1alpha1.SecretRef buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.tekton.triggers.v1alpha1.SecretRef secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String secretKey,java.lang.String secretName) {
    return (A)withSecretRef(new SecretRef(secretKey, secretName));
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.tekton.triggers.v1alpha1.SecretRef item) {
    return new io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder().build());
  }
  public io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.tekton.triggers.v1alpha1.SecretRef item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitHubInterceptorFluentImpl that = (GitHubInterceptorFluentImpl) o;
    if (eventTypes != null ? !eventTypes.equals(that.eventTypes) :that.eventTypes != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(eventTypes,  secretRef,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.tekton.triggers.v1alpha1.SecretRefFluentImpl<io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<N>> implements io.fabric8.tekton.triggers.v1alpha1.GitHubInterceptorFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.tekton.triggers.v1alpha1.SecretRef item) {
      this.builder = new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder(this);
    }
    io.fabric8.tekton.triggers.v1alpha1.SecretRefBuilder builder;
    public N and() {
      return (N) GitHubInterceptorFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
